exceptiontools.TonalHarmonyError
================================

.. abjad-lineage:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError

.. autoclass:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError.__unicode__
   :noindex:
